#! /bin/sh

VSN=1.1

if (test -z "$1" -o $# -ne 1) ; then
    echo " Usage: setup.sh OTP_DIR"
    echo " where: OTP_DIR   -- full path name of the Erlang OTP"
    echo "                     installation directory"
    exit
fi

DIALYZER_OTP_DIR=$1
DIALYZER_OTP_RTS=$DIALYZER_OTP_DIR/bin/erl

echo "Setting up Dialyzer..."
if (test -z `which wish`) ; then
    echo "  Could not find the 'wish' Tcl/Tk program (needed for gs) in the path."
    echo "  Please add it."
    exit
else
    echo "  The 'wish' executable was found in the path"
fi

if (test -d ebin) ; then
    echo "  The 'ebin' directory already exists..."
else
    echo "  Creating 'ebin/'"
    mkdir ebin
fi

if (test -d plt) ; then
    echo "  The 'plt'  directory already exists..."
else
    echo "  Creating 'plt/'"
    mkdir plt
fi

if (test -f plt/dialyzer_empty_plt) ; then
    echo "  An empty persistent lookup table (PLT) already exists..."
else
    echo "  Creating empty persistent lookup table (PLT)"
    touch plt/dialyzer_empty_plt
fi

if (test -f $DIALYZER_OTP_RTS) ; then
    ## remove the file unconditionally to avoid problems when using
    ## symbolic links across filesystems in different machines.
    rm -f src/hipe_icode_type.hrl
    echo "  Creating a symbolic link to" $DIALYZER_OTP_DIR/hipe_icode_type.hrl
    ln -s $DIALYZER_OTP_DIR/lib/hipe*/icode/hipe_icode_type.hrl src
    cd src
    sed -e "s;%VSN%;$VSN;" dialyzer.hrl.src > dialyzer.hrl
    $DIALYZER_OTP_RTS -make
    mv *.beam ../ebin
    sed -e "s;%VSN%;$VSN;" dialyzer.app.src > ../ebin/dialyzer.app
    cd ..
    sed -e "s;%OTP_DIR%;$DIALYZER_OTP_DIR;" \
	-e "s;%VSN%;$VSN;" -e "s;%DATE%;`date`;" \
	-e "s;%DIALYZER_DIR%;`pwd`;" src/dialyzer.src > dialyzer
    chmod +x dialyzer
    echo "  Dialyzer is bootstrapping itself..."
    ./dialyzer --src --command-line "`pwd`/src"
    echo "Dialyzer setup done!"
    echo "  For the full set of Dialyzer options type: ./dialyzer --help"
else
    echo "Could not find ${DIALYZER_OTP_RTS}"
fi
